+++
title = "TOC with TODO enabled (default)"
description = """
  TODO states if present are prefixed to the headings -- both in the body
  and TOC.
  """
tags = ["export-option", "toc", "todo", "enable"]
draft = false
+++

<div class="ox-hugo-toc toc">
<div></div>

<div class="heading">Table of Contents</div>

- [No TODO state](#no-todo-state)
- [<span class="org-todo todo TODO">TODO</span> Something to do](#something-to-do)
- [<span class="org-todo done DONE">DONE</span> Something done](#something-done)

</div>
<!--endtoc-->

<style>
.org-todo {
    font-size: 0.8em;
    font-weight: 700;
}
/* *** Org TODO set to TODO state */
.org-todo.todo {
    color: #e60000;
}
/* *** Org TODO set to DONE state */
.org-todo.done {
    color: green;
}
</style>


## No TODO state {#no-todo-state}


## <span class="org-todo todo TODO">TODO</span> Something to do {#something-to-do}


## <span class="org-todo done DONE">DONE</span> Something done {#something-done}
